..
   Template for the html module rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/module.rst

lbfgsb.scalar\_function
=======================

.. automodule:: lbfgsb.scalar_function

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      :template: class.rst
      ScalarFunction
   
   

   
   
   



